==> fet-5.1.8.tar.bz2: fet-5.1.8/src/interface/splityearform.h <==
/***************************************************************************
                          splityearform.h  -  description
                             -------------------
    begin                : 10 Aug 2007
    copyright            : (C) 2007 by Lalescu Liviu
    email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef SPLITYEARFORM_H
#define SPLITYEARFORM_H

#include "splityearform_template.h"

#include "timetable_defs.h"
#include "timetable.h"
#include "fet.h"

#include <q3combobox.h>
#include <qmessagebox.h>
#include <q3groupbox.h>
#include <qspinbox.h>
#include <qcheckbox.h>
#include <qpushbutton.h>
#include <qlineedit.h>
#include <q3textedit.h>

class SplitYearForm : public SplitYearForm_template  {
public:
	QString year;
	
	SplitYearForm(const QString year);
	~SplitYearForm();

	void ok();
	void numberOfCategoriesChanged();
	void category1Changed();
	void category2Changed();
	void category3Changed();
	
	void help();
	void reset();
};

#endif

==> fet-5.25.0.tar.bz2: fet-5.25.0/src/interface/splityearform.h <==
/***************************************************************************
                          splityearform.h  -  description
                             -------------------
    begin                : 10 Aug 2007
    copyright            : (C) 2007 by Lalescu Liviu
    email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef SPLITYEARFORM_H
#define SPLITYEARFORM_H

#include <QString>

#include <QSignalMapper>

#include "ui_splityearform_template.h"

#include "timetable_defs.h"
#include "timetable.h"
#include "fet.h"

const int MAX_CATEGORIES=14;
const int MAX_SUBGROUPS_PER_YEAR=MAX_TOTAL_SUBGROUPS;

class SplitYearForm : public QDialog, Ui::SplitYearForm_template  {
	Q_OBJECT

private:
	QString _sep;
	int _nCategories;
	int _nDivisions[MAX_CATEGORIES];
	QStringList _divisions[MAX_CATEGORIES];
	
	QListWidget* listWidgets[MAX_CATEGORIES];
	
	QSignalMapper mapperModify;
	
public:
	QString year;
	
	SplitYearForm(QWidget* parent, const QString& _year);
	~SplitYearForm();
	
	void updateNumberOfSubgroups();
	void updateDivisionsLabel();
	
public slots:
	void tabIndexChanged(int i);
	
	void ok();
	void numberOfCategoriesChanged();
	
	void addClicked();
	void modifyClicked();
	void modifyDoubleClicked(int i);
	void removeClicked();
	void removeAllClicked();
	
	void help();
	void reset();
};

#endif
